==> datashuttle-0.3.0.tar.gz: datashuttle-0.3.0/docs/source/pages/how_tos/choose-a-terminal.md <==
(how-to-choose-a-terminal)=

# How to Choose a Terminal

**datashuttle**'s graphical interface can run in almost any terminal—but
native Windows and macOS terminals may display with rendering errors.

If you are using Linux, the native terminal will work without issue.


::::{tab-set}

:::{tab-item} Bad Rendering

```{image} /_static/screenshots/how-to-choose-a-terminal-bad-dark.png
   :align: center
   :class: only-dark
   :width: 900px
```
```{image} /_static/screenshots/how-to-choose-a-terminal-bad-light.png
   :align: center
   :class: only-light
   :width: 900px
```
<br>

:::

:::{tab-item} Good Rendering

```{image} /_static/screenshots/how-to-choose-a-terminal-good-dark.png
   :align: center
   :class: only-dark
   :width: 900px
```
```{image} /_static/screenshots/how-to-choose-a-terminal-good-light.png
   :align: center
   :class: only-light
   :width: 900px
```
<br>


:::

::::

## Choosing a terminal for Windows or macOS

::::{tab-set}

:::{tab-item} Windows

For Windows, we recommend using
[Terminal](https://apps.microsoft.com/detail/9n0dx20hk701?rtc=1&hl=en-gb&gl=GB),
Window's own high-powered terminal available for free from the
Microsoft Store.

**datashuttle** will run in Command Prompt (`cmd.exe`), Powershell (`ps.exe`)
or [Anaconda Prompt](https://docs.anaconda.com/free/anaconda/getting-started/index.html),
but may display with rendering errors.

:::

:::{tab-item} macOS

On macOS, we recommend using next-generation terminal emulators such
as [Warp](https://warp.dev/)
or [Wezterm](https://wezfurlong.org/wezterm/index.html).
Both come with easy-to-use installers.

**datashuttle** will run on the native macOS terminal but may display
with rendering errors.

:::

::::

## Getting started with the Graphical Interface

Once you've chosen a terminal, get started with
**datashuttle** with our [Getting Started Tutorial](tutorial-getting-started).

==> datashuttle-0.5.2.tar.gz: datashuttle-0.5.2/docs/source/pages/how_tos/choose-a-terminal.md <==
(how-to-choose-a-terminal)=

# How to Choose a Terminal

**datashuttle**'s graphical interface can run in almost any terminal—but
native Windows and macOS terminals may display with rendering errors.
See below for recommended terminals for these operating systems.

If you are using Linux, the native terminal will work without issue.


::::{tab-set}

:::{tab-item} Good Rendering

```{image} /_static/screenshots/how-to-choose-a-terminal-good-dark.png
   :align: center
   :class: only-dark
   :width: 900px
```
```{image} /_static/screenshots/how-to-choose-a-terminal-good-light.png
   :align: center
   :class: only-light
   :width: 900px
```
<br>


:::

:::{tab-item} Bad Rendering

```{image} /_static/screenshots/how-to-choose-a-terminal-bad-dark.png
   :align: center
   :class: only-dark
   :width: 900px
```
```{image} /_static/screenshots/how-to-choose-a-terminal-bad-light.png
   :align: center
   :class: only-light
   :width: 900px
```
<br>

:::

::::

## Choosing a terminal for Windows or macOS

::::{tab-set}

:::{tab-item} Windows

For Windows, we recommend using
[Terminal](https://apps.microsoft.com/detail/9n0dx20hk701?rtc=1&hl=en-gb&gl=GB)—Window's
own high-powered terminal available for free on the
Microsoft Store.

**datashuttle** will run in Command Prompt (`cmd.exe`), Powershell (`ps.exe`)
or [Anaconda Prompt](https://docs.anaconda.com/free/anaconda/getting-started/index.html),
but may display with rendering errors.

:::

:::{tab-item} macOS

On macOS we recommend using next-generation terminal emulators such
as [Warp](https://warp.dev/)
or [Wezterm](https://wezfurlong.org/wezterm/index.html).
Both come with easy-to-use installers.

**datashuttle** will run on the native macOS terminal but may display
with rendering errors.

:::

::::

## Getting started with the Graphical Interface

Once you've chosen a terminal, get started with
**datashuttle** with our [Getting Started Tutorial](tutorial-getting-started).
